@@ -1,11 +1,22 @@
+'CLI module'
+
+from os import linesep
 import sys
+import logging
 import argparse
 from time import sleep
 
-from .lookup import get_as_data
+from . import __full_version__
 from .exceptions import AddressFormatError, LookupError
+from .lookup import get_as_data
 
 
+logging.basicConfig(
+    level=logging.DEBUG,
+    format='[%(levelname)s] %(message)s'
+)
+logger = logging.getLogger(__name__)
+
 def main():
     description = ('Client to return autonomous system information for '
                    'IPv4 addresses')
@@ -23,9 +34,21 @@ def main():
     parser.add_argument('-r', '--raw', action='store_true',
                         help='display internal ASData object showing the value '
                              'of each known field in the AS data')
-    parser.add_argument('address', nargs='*', help='IPv4 address(es) on which to perform AS lookup')
+    parser.add_argument('-V', '--version', action='store_true',
+                        help='display package version')
+    parser.add_argument('-v', '--verbose', dest='loglevel', action='store_const',
+                        const=logging.DEBUG, default=logging.WARNING,
+                        help='show verbose output')
+    parser.add_argument('address', nargs='*',
+                        help='IPv4 address(es) on which to perform AS lookup')
     args = parser.parse_args()
 
+    logging.getLogger().setLevel(args.loglevel)
+
+    # Print software version
+    if args.version:
+        parser.exit(status=0, message=__full_version__ + linesep)
+
     # Print header lines if specified
     if args.header:
         print('-' * 50)
